# Changelog

## [stormi-v0.2.2](https://github.com/pinellolab/stormi/compare/stormi-v0.2.1...stormi-v0.2.2) (2025-03-25)

### Bug Fixes

* **pyproject:** add ipykernel to interactive group ([33a43ab](https://github.com/pinellolab/stormi/commit/33a43aba25014984c25626e2971a93b4073aba26))
* **pyproject:** update version lower bounds for conda-forge compat ([cc270cd](https://github.com/pinellolab/stormi/commit/cc270cdaa475bdee81704811daaf7708f2ffbdbd))
